/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.arquillian.secureejb.demo;

import java.security.PrivilegedAction;

import javax.ejb.EJB;
import javax.ejb.EJBAccessException;
import javax.security.auth.Subject;
import javax.security.auth.login.LoginContext;
import javax.security.auth.login.LoginException;

import org.jboss.arquillian.container.test.api.Deployment;
import org.jboss.arquillian.junit.Arquillian;
import org.jboss.arquillian.secureejb.JBossLoginContextFactory;
import org.jboss.shrinkwrap.api.ShrinkWrap;
import org.jboss.shrinkwrap.api.spec.JavaArchive;
import org.jboss.shrinkwrap.api.spec.WebArchive;
import org.junit.Test;
import org.junit.runner.RunWith;

/**
 * Integration tests demonstrating access to user roles and principal.
 */
@RunWith(Arquillian.class)
public class SecureSessionBeanIT {

    @EJB
    private SecureSessionBean sut;

    @Deployment
    public static WebArchive createTestArchive() {
        JavaArchive ejbJar = ShrinkWrap.create(JavaArchive.class, "security-demo-test.jar")
                .addClasses(SecureSessionBean.class, SecurityRoles.class)
                .addAsResource("META-INF/ejb-jar.xml")
                .addAsResource("META-INF/jboss-ejb3.xml")
                ;
        WebArchive webArchive = ShrinkWrap.create(WebArchive.class, "test.war")
                .addClasses(JBossLoginContextFactory.class)
                .addAsResource("users.properties")
                .addAsResource("roles.properties")
                .addAsLibrary(ejbJar)
                ;
        System.out.println("ejbJar: " + ejbJar.toString(true));
        System.out.println("webArchive: " + webArchive.toString(true));
        return webArchive;
    }

    @Test
    public void testAuthorisedSecureOperation() throws LoginException {
        LoginContext loginContext = JBossLoginContextFactory.createLoginContext("user1", "password");
        loginContext.login();
        try {
            Subject.doAs(loginContext.getSubject(), new PrivilegedAction<Void>() {

                @Override
                public Void run() {
                    sut.performSecureOperation();
                    return null;
                }

            });
        } finally {
            loginContext.logout();
        }
    }

    @Test(expected=EJBAccessException.class)
    public void testUnauthorisedSecureOperation() throws LoginException {
        LoginContext loginContext = JBossLoginContextFactory.createLoginContext("user2", "foobar");
        loginContext.login();
        try {
            Subject.doAs(loginContext.getSubject(), new PrivilegedAction<Void>() {

                @Override
                public Void run() {
                    sut.performSecureOperation();
                    return null;
                }

            });
        } finally {
            loginContext.logout();
        }
    }

    
    @Test(expected=EJBAccessException.class)
    public void testDenyAll(){
        sut.unauthorisedOperation();
    }
}
